function Q = get_Q_data(subjName)

try,
    Q.Demog = inner_Demog(subjName);
catch,
    Q.Demog.scores = [NaN NaN NaN];
    Q.Demog.labels = {'Sex', 'Age', 'Desktop'};
end;
try,
    Q.PHQ4 = inner_PHQ4(subjName);
catch
    Q.PHQ4.scores = NaN * ones(1, 2);
    Q.PHQ4.raw = NaN * ones(1, 4);
    Q.PHQ4.labels = {'PHQ4_Anx', 'PHQ4_Dep'};
end;
try,
    Q.BP = inner_BP(subjName);
catch,
    Q.BP.scores = NaN * ones(1, 4);
    Q.BP.labels = {'PhysicalAggr', 'VerbalAggr', 'Anger', 'Hostility'};
    Q.BP.raw = NaN * ones(1, 29);
end;
try,
    Q.aware = inner_aware(subjName);
catch,
    Q.aware.scores = NaN * ones(1, 6);
    Q.aware.labels = {'BlueSafe1', 'BlueThreat1', 'BlueSafe2', 'BlueThreat2', 'BlueSafe3', 'BlueThreat3'};
end;

end

function thisQ = inner_Demog(subjName)
fn = ['dataQ_demoQ_' subjName '.txt'];
O = parseFile(fn);
thisQ.scores = [];
thisQ.labels = {};
for iQ = 1:length(O.Raw{1}),
    qText = O.Raw{1}{iQ}{1};
    ans0 = O.Raw{1}{iQ}{2};
    ansval = [];
    thislabel = 'xxx';
    if strcmp(qText, 'demoQ_Q_ 0'),
        if length(find(strcmp(ans0, {'Male', 'Man', 'Mann'}))) >= 1,
            ansval = 1;
        elseif length(find(strcmp(ans0, {'Female', 'Vrouw', 'Frau'}))) >= 1,
            ansval = 0;
        else,
            ansval = -1;
        end;
        thislabel = 'Sex';
    elseif strcmp(qText, 'demoQ_Q_ 1'),
        digind0 = regexp(ans0, '\d');
        if length(digind0) > 0,
            ansval = str2num(ans0(digind0));
        else,
            ansval = NaN;
        end;
        thislabel = 'Age';
    elseif strcmp(qText, 'demoQ_Q_ 2'),
        if length(find(strcmp(ans0, {'Desktop'}))) >= 1,
            ansval = 1;
        else,
            ansval = 0;
        end;
        thislabel = 'Desktop';
    end;
    thisQ.scores = [thisQ.scores ansval];
    if ~isempty(ansval),
        thisQ.labels{length(thisQ.labels) + 1} = thislabel;
    end;
end;
thisQ.raw = thisQ.scores;
end

function thisQ = inner_PHQ4(subjName)
anscats = {'(1) Not at all', '(2) Several days', '(3) More days than not', '(4) Nearly every day'};
codingvec = [];
fn = ['dataQ_PHQ4_' subjName '.txt'];
O = parseFile(fn);
scores0 = [];
for iQ = 1:length(O.Raw{1}),
    ans0 = O.Raw{1}{iQ}{2};
    ansval = -1;
    for iAnsCat = 1:length(anscats)
        if strcmp(ans0, anscats{iAnsCat}),
            ansval = iAnsCat;
        end;
    end;
    if ansval == -1,
        fprintf([num2str(666) ' PHQ4\n']);
    end;
    scores0 = [scores0 ansval];
end;
thisQ.raw = scores0;
thisQ.scores = [sum(scores0(1:2)) sum(scores0(3:4))];
thisQ.labels = {'PHQ4_Anx', 'PHQ4_Dep'};
end

function thisQ = inner_aware(subjName)
anscats = {{'Yellow'}, {'Blue'}};
codingvec = [];
fn = ['dataQ_awareQ_' subjName '.txt'];
O = parseFile(fn);
thisQ.raw = [];
thisQ.scores = [];
thisQ.labels = {};
for iT = 1:3
    scores0 = [];
    for iQ = 1:length(O.Raw{iT}),
        ans0 = O.Raw{iT}{iQ}{2};
        ansval = -1;
        for iAnsCat = 1:length(anscats)
            if length(find(strcmp(ans0, anscats{iAnsCat}))) >= 1,
                ansval = iAnsCat;
            end;
        end;
        if ansval == -1,
            fprintf('666 awareQ\n');
        end;
        scores0 = [scores0 ansval - 1];
    end;
    thisQ.raw = [thisQ.raw scores0];
    thisQ.scores = [thisQ.scores scores0];
    thisQ.labels{end + 1} = ['BlueSafe' num2str(iT)];
    thisQ.labels{end + 1} = ['BlueThreat' num2str(iT)];
end
end

function thisQ = inner_BP(subjName)
anscats = {{'1'}, {'2'},{'3'},{'4'},{'5'},{'6'},{'7'}};
codingvec = [];
fn = ['dataQ_BPQ_' subjName '.txt'];
O = parseFile(fn);
codingvec = [1 1 1 1 1 1 -1 1 1 1 1 1 1 1 1 1 1 -1 1 1 1 1 1 1 1 1 1 1 1];
scores0 = [];
for iQ = 1:length(O.Raw{1}),
    ans0 = O.Raw{1}{iQ}{2};
    ansval = -1;
    for iAnsCat = 1:length(anscats)
        if length(find(strcmp(ans0, anscats{iAnsCat}))) >= 1,
            ansval = iAnsCat;
        end;
    end;
    if ansval == -1,
        fprintf('666 BP\n');
    end;
    if codingvec(iQ) == -1,
        ansval = 8 - ansval;
    end;
    scores0 = [scores0 ansval];
end;
thisQ.raw = scores0;
PhysAggr = sum(scores0(1:9));
VerbalAggr = sum(scores0(10:14));
Anger = sum(scores0(15:21));
Hostility = sum(scores0(22:29));
thisQ.scores = [PhysAggr VerbalAggr Anger Hostility];
thisQ.labels = {'PhysicalAggr', 'VerbalAggr', 'Anger', 'Hostility'};
end
