function O = parseSubj(subjName)

O.Q = get_Q_data(subjName);

data0 = parseVAEST(subjName);
try
    O.VAEST.Tables = analyze_VAEST(data0, O.Q);
catch
    O = [];
    return;
end

O.Q.cueCorrect.raw = O.VAEST.Tables.cueCorrect;
O.Q.cueCorrect.scores = O.VAEST.Tables.cueCorrect;
O.Q.cueCorrect.labels = {'cueCorrect'};

function O = parseVAEST(subjName)
fn = ['dataVAEST0_' subjName '.txt'];
O = parseFile(fn);

function Tables = analyze_VAEST(O, Q)
Tables.M = [];
part0 = 0;
prevBlock = -1;
prevTrial = -1;
for iTrial = 1:length(O.Raw),
    try
        % Extract relevant trial vars
        RT = getfield(O.Raw{iTrial}, 'RT');
        if isempty(RT),
            RT = NaN;
        end;
        acc = getfield(O.Raw{iTrial}, 'acc');
        if acc < 1
            acc = 0;
        end;
        iTrial0 = getfield(O.Raw{iTrial}, 'iTrial');
        if iTrial0 == prevTrial
            fprintf('Repeat-save of trial.\n');
            continue;
        end
        prevTrial = iTrial0;
        iBlock = getfield(O.Raw{iTrial}, 'iBlock');
        if iBlock <= prevBlock && iTrial0 == 0
            part0 = part0 + 1;
        end;
        prevBlock = iBlock;
        if part0 < 2
            continue;
        end
        distrType = getfield(O.Raw{iTrial}, 'distrType');
        try
            blockType = getfield(O.Raw{iTrial}, 'blockType');
        catch
            fprintf('Pilot-error: no blockType defined, so default to 2');
            blockType = 2;
        end
        Durvec = getfield(O.Raw{iTrial}, 'trialDurs');
        cueSafeThreat = getfield(O.Raw{iTrial}, 'cueSafeThreat');
        cueThreat = cueSafeThreat{2}; % 0 = yellow, 1 = blue
        CSI = Durvec{3};
        newrow = [iTrial0 iBlock distrType CSI cueThreat NaN RT acc];
        Tables.M = [Tables.M; newrow];
    catch
        dfdf=0;
    end
end;

if part0 ~= 2
    fprintf('Incorrect number of parts.\n');
    error('Incorrect number of parts.');
end

if size(Tables.M, 1) ~= (12 * 25)
    fprintf('Incorrect number of trials.\n');
    error('Incorrect number of trials.');
end

% disp(Tables.M);

if var(Tables.M(:, 5)) > 0
    fprintf('Inconsistent cue indices!\n');
else
    fprintf(['CueThreat was ' num2str(cueThreat), '; cueSafeThreat{1} = ' num2str(cueSafeThreat{1}) ', cueSafeThreat{2} = ' num2str(cueSafeThreat{2}) '\n']);
end;

%   Stims: Color 1 (index 0) = Yellow, Color 2 (index 1) = Blue
% 	this.texts.push("After this cue, no angry face ever appeared.");
% 	this.texts.push("After this cue, the angry face sometimes appeared.");
%   this.options.push(["Yellow", "Blue"]);
if Q.aware.scores(5) == 0 && Q.aware.scores(6) == 1
    threatWasBlue = 1;
elseif Q.aware.scores(5) == 1 && Q.aware.scores(6) == 0
    threatWasBlue = 0;
else
    threatWasBlue = NaN;
end
Tables.cueThreat = cueThreat;
Tables.cueCorrect = NaN;
if cueThreat == threatWasBlue
    Tables.cueCorrect = 1;
else
    Tables.cueCorrect = 0;
end;
Mtmp = Tables.M;

% Remove trials
Mtmp(1:4, :) = [];
f = find(Mtmp(:, end - 1) < 100); %
Mtmp(f, :) = [];
f = find(Mtmp(:, end - 1) > 2500); % Response window anyway
Mtmp(f, :) = [];
removeOutliers = 1;
f = find(Mtmp(:, 1) < 1);
Mtmp(f, :) = [];

indepvec = [3 4];
Mtmp2 = Mtmp;
fAcc = find(Mtmp2(:, end) == 1);
[meanvec, idmat, Nvec, SDvec, Tables.levels, Tables.levelVals] = teg_values_per_cell(Mtmp2(fAcc, end - 1), Mtmp2(fAcc, indepvec), 1, removeOutliers);
Tables.RT = [meanvec Nvec SDvec];
Tables.RTSD = [SDvec ./ meanvec Nvec SDvec];
[meanvec, idmat, Nvec, SDvec] = teg_values_per_cell(Mtmp2(:, end), Mtmp2(:, indepvec), 0);
Tables.acc = [meanvec Nvec SDvec];
